@@ -122,7 +122,7 @@ function render() {
     }
     let objType = study.objId.split("-")[0]; // 'screen' or 'project'
     studyContainers[idrId][objType].push(study);
-    studyContainers[idrId]["description"] = model.getStudyDescription(study);
+    studyContainers[idrId]["description"] = study["StudyDescription"];
     let pubmed = model.getStudyValue(study, "PubMed ID");
     if (pubmed) {
       studyContainers[idrId]["pubmed_id"] = pubmed.split(" ")[1];
@@ -211,11 +211,15 @@ function render() {
 
 // --------- Render utils -----------
 
-function imageCount(idrId) {
+function imageCount(idrId, container) {
+  // idrId e.g. "idr0001". container optional e.g. "experimentA"
   if (!model.studyStats) return "";
 
   let containers = model.studyStats[idrId];
   if (!containers) return "";
+  if (container) {
+    containers.filter((c) => c.Container == container);
+  }
 
   let imgCount = containers
     .map((row) => row["5D Images"])
